import { Keypair } from '@solana/web3.js';
import { createCandyMachineOperation } from './createCandyMachine.mjs';
import { findCandyMachineByAdddressOperation } from './findCandyMachineByAddress.mjs';
import { findCandyMachinesByPublicKeyFieldOperation } from './findCandyMachinesByPublicKeyField.mjs';
import { ModuleClient } from '../../types/ModuleClient.mjs';
import { CreatedCandyMachineNotFoundError } from '../../errors/CandyMachineError.mjs';
import { candyMachineDataFromConfig } from './config/fromConfig.mjs';
import { convertToPublickKey } from '../../types/PublicKeyString.mjs';

class CandyMachineClient extends ModuleClient {
  findCandyMachineByAddress(address) {
    const operation = findCandyMachineByAdddressOperation(address);
    return this.metaplex.operations().execute(operation);
  }

  findCandyMachinesByWallet(wallet) {
    return this.metaplex.operations().execute(findCandyMachinesByPublicKeyFieldOperation({
      type: 'wallet',
      publicKey: wallet
    }));
  }

  findCandyMachinesByAuthority(authority) {
    return this.metaplex.operations().execute(findCandyMachinesByPublicKeyFieldOperation({
      type: 'authority',
      publicKey: authority
    }));
  }

  async createCandyMachine(input) {
    const operation = createCandyMachineOperation(input);
    const output = await this.metaplex.operations().execute(operation);
    const candyMachine = await this.findCandyMachineByAddress(output.candyMachineSigner.publicKey);

    if (candyMachine === null) {
      throw new CreatedCandyMachineNotFoundError(output.candyMachineSigner.publicKey);
    }

    return {
      candyMachine,
      ...output
    };
  }

  createCandyMachineFromConfig(config, opts) {
    const {
      candyMachineSigner = Keypair.generate()
    } = opts;
    const candyMachineData = candyMachineDataFromConfig(config, candyMachineSigner.publicKey);
    const walletAddress = convertToPublickKey(config.solTreasuryAccount);
    return this.createCandyMachine({
      candyMachineSigner,
      walletAddress,
      authorityAddress: opts.authorityAddress,
      ...candyMachineData
    });
  }

}

export { CandyMachineClient };
//# sourceMappingURL=CandyMachineClient.mjs.map
